use strict;

1;

=head1 NAME

Lingua::Identify::Nothing - Module for tests

=head1 SYNOPSIS

Nothing here is meant for public consumption. This module is to be
loaded by Lingua::Identify.

=head1 DESCRIPTION

This module serves to exercise part of I<Lingua::Identify>'s code.

=head1 SEE ALSO

Lingua::Identify(3).

=head1 AUTHOR

Jose Castro, C<< <cog@cpan.org> >>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2004 by Jose Alves de Castro

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.4 or,
at your option, any later version of Perl 5 you may have available.

=cut
